Improve this doc

# Error: ngRepeat:iexp
Invalid Expression

    Expected expression in form of '_item_ in _collection_[ track by _id_]' but got '{0}'.

## Description

Occurs when there is a syntax error in an ngRepeat's expression. The expression should be in the form 'item in collection[ track by id]'.

Be aware, the ngRepeat directive parses the expression using a regex before sending collection and optionally id to the AngularJS parser. This error comes from the regex parsing.

To resolve, identify and fix errors in the expression, paying special attention to the 'in' and 'track by' keywords in the expression.

Please consult the api documentation of ngRepeat to learn more about valid syntax.